@@ -82,9 +82,14 @@ def tasks_read_remote(service, TASKLIST1):
             print("X...", err)
     return tasks_remote
 
+
+# ================================================================================
+#                           like IMPORT
+# --------------------------------------------------------------------------------
+
 def dict2org(tasks_dict):
     """
-    Converts nested dict {tasklist: [tasks]} to org-mode lines.
+    Converts nested dict {tasklist: [tasks]} to org-mode lines.   LIKE IMPORT
     """
     lines = ["* GOOGLE TASKS"]
     for tasklist, tasks in tasks_dict.items():
@@ -92,7 +97,29 @@ def dict2org(tasks_dict):
         lines.append(f"** {tasklist}")
         for t in tasks:
             lines.append("")
-            lines.append(f"*** TODO {t['title']}")
+            # -------- ------------------------------- SCHEDULED has TODO if not else   (import)
+            #print(f"{tasklist:25s}@@@{t['title'].strip()}@I@")
+
+            if t['title'].strip().find("DOING") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t['title'].strip().find("WAITING") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t['title'].strip().find("TODO") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t['title'].strip().find("DELEGATED") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t['title'].strip().find("POSTPONED") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t['title'].strip().find("DONE") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t['title'].strip().find("CANCELED") == 0:
+                lines.append(f"*** {t['title']}")
+            elif t.get("due"):
+                lines.append(f"*** TODO {t['title']}")
+            else:
+                lines.append(f"*** {t['title']}")
+            #------------------------
+
             if t.get("due"):
                 due_org = dt_to_org(t["due"])
                 lines.append(f"SCHEDULED: <{due_org}>")
@@ -114,12 +141,12 @@ def dict2org(tasks_dict):
     return lines
 
 # ================================================================================
-#
+#            like EXPORT
 # --------------------------------------------------------------------------------
 
 def org2dict(org_lines):
     """
-    convert due to the T Z format
+    convert due to the T Z format  ----- like EXPORT
     """
     tasks_dict = {}
     current_tasklist = None
@@ -135,11 +162,22 @@ def org2dict(org_lines):
                 current_task = None
             current_tasklist = line[3:]
             tasks_dict.setdefault(current_tasklist, [])
-        elif line.startswith("*** TODO "):
+        elif line.startswith("*** "): # ------------------------------- exporting items
+            # ---------  TODO is bound to Schedule, I will skip it here
+            mytitle = line.replace("*** ", "") # ALWAYS REMOVE ***  line[9:].strip()
+            mytitle = mytitle.replace("TODO", "") # dont propagate TODO - it is <-> scheduled
+            mytitle = mytitle.strip(" ")
+        #elif line.startswith("*** TODO ") or line.startswith("*** DOING "):
             # Save previous task before starting new one
+            #if line.startswith("*** DOING "):
+            #else:
+            #    mytitle = line[8:].strip()
+            ## ------ ----------------------- formulate task
             if current_task and current_tasklist:
-                tasks_dict[current_tasklist].append(current_task)
-            current_task = {"title": line[8:].strip(), "due": None, "updated": None, "status": "needsAction", "notes": ""}
+                tasks_dict[current_tasklist].append(current_task) # Like Finish The Previous Task and GO ON
+            # -- initiate
+            #print(f"{current_tasklist:25s}@@@{mytitle}@E@")
+            current_task = {"title": mytitle, "due": None, "updated": None, "status": "needsAction", "notes": ""}
         elif line.startswith("SCHEDULED: <") and current_task:
             current_task["due"] = line[len("SCHEDULED: <"):-1]
             current_task["due"] = current_task["due"].split()[0] + "T00:00:00.000Z"
@@ -209,7 +247,7 @@ def tasks_compare_rl(remote_dict, local_dict):
 
 
     print(fg.default)
-    print("_" * 15, "L", "_" * 20, "R", "_" * 15,"starting local->remote:")
+    print("_" * 15, "L", "_" * 20, "R", "_" * 15," action on local->remote:")
 
     for tasklist, local_tasks in local_dict.items():
         if tasklist in remote_dict:
@@ -371,94 +409,10 @@ def update_remote_task(service, TASKLIST1, local_dict, tasklist_title, task_titl
     except HttpError as err:
         print(f"Failed to update task '{task_title}': {err}")
 
-# # ================================================================================
-# # MAIN
-# # --------------------------------------------------------------------------------
-
-# #@click.command()
-# #@click.argument("command")
-# ##@click.option("--command", "-c", default="rprint", help="rprint  lprint  rlcomp")
-# def main(command):
-#     """Shows basic usage of the Tasks API.
-#     Prints the title and ID of the first 10 task lists.
-#     """
-#     creds = None
-#     # The file token.json stores the user's access and refresh tokens, and is
-#     # created automatically when the authorization flow completes for the first
-#     # time.
-#     if os.path.exists(TOKEN):
-#         creds = Credentials.from_authorized_user_file(TOKEN, SCOPES)
-#     # If there are no (valid) credentials available, let the user log in.
-#     if not creds or not creds.valid:
-#         print(f"D...  TOKEN: {TOKEN}")
-#         if creds and creds.expired and creds.refresh_token:
-#             creds.refresh(Request())
-#         else:
-#             flow = InstalledAppFlow.from_client_secrets_file(
-#                     CRED, SCOPES
-#             )
-#             creds = flow.run_local_server(port=0)
-#         # Save the credentials for the next run
-#         with open(TOKEN, "w") as token:
-#             token.write(creds.to_json())
-
-#     TASKLIST = {}
-#     try:
-#         service = build("tasks", "v1", credentials=creds)
-
-#         # Call the Tasks API
-#         results = service.tasklists().list(maxResults=10).execute()
-#         items = results.get("items", [])
-
-#         if not items:
-#             print("No task lists found.")
-#             return
-
-#         #print("D... ===============================Task lists:")
-#         for item in items:
-#             #print(f"D...   * {item['title']} ({item['id']})")
-#             TASKLIST[item['id']] = item['title']
-#     except HttpError as err:
-#         print(err)
-
-#     # ===========================================================   command section ============
-#     if command == "rprint" or command == "r": # I NEED THIS TO CREATE ORGMODE AGENDA
-#         tarem = tasks_read_remote(service, TASKLIST)
-#         #print(tarem)
-#         print()
-#         for i in dict2org(tarem): print(i)
-#     elif command == "lprint" or command == "l": # I dont need it really - just to see
-#         taloc = tasks_read_file()
-#         print(taloc)
-#         print()
-#         for i in dict2org(taloc): print(i)
-#         res = org2dict(   dict2org(taloc)  )
-#         print()
-#         print(res)
-#         print()
-#         for i in dict2org(res): print(i)
-#     elif command == "rlcomp" or command == "rl":
-#         tarem = tasks_read_remote(service, TASKLIST)
-#         taloc = tasks_read_file()
-#         to_push_new, to_update = tasks_compare_rl(tarem, taloc)
-#         print("TO PUSH NEW")
-#         print(to_push_new)
-#         add_tasks_to_remote(service, TASKLIST, taloc, to_push_new)
-#         #
-#         #print("TO UPDATE")
-#         #print(to_update)
-#     else:
-#         print("X... unknown command ")
 
 
 
 
-
-# #@click.group()
-# #def cli():
-# #    pass
-
-
 # ================================================================================
 # IMPORT MAIN
 # --------------------------------------------------------------------------------
@@ -475,13 +429,27 @@ def main_import(command="rprint"):
     # created automatically when the authorization flow completes for the first
     # time.
     if os.path.exists(TOKEN):
+        #print(f"D...  ....  TOKEN: {TOKEN}")
         creds = Credentials.from_authorized_user_file(TOKEN, SCOPES)
+    else:
+        print("X... NO token")
     # If there are no (valid) credentials available, let the user log in.
     if not creds or not creds.valid:
-        print(f"D...  TOKEN: {TOKEN}")
+        print(f"D...  creds NOT VALID....  ")
         if creds and creds.expired and creds.refresh_token:
-            creds.refresh(Request())
+            ok = False
+            try:
+                print(f"D...  refreshing creds  ")
+                creds.refresh(Request())
+                ok = True
+            except Exception as err:
+                print(err)
+                print("i... try to remove ", TOKEN)
+            if not ok:
+                print("X... sorry end")
+                sys.exit(1)
         else:
+            print(f"D...  creds else: ")
             flow = InstalledAppFlow.from_client_secrets_file(
                     CRED, SCOPES
             )
@@ -514,6 +482,7 @@ def main_import(command="rprint"):
         tarem = tasks_read_remote(service, TASKLIST)
         #print(tarem)
         print()
+        print()
         for i in dict2org(tarem): print(i)
     else:
         print(f"X... command not recognized /{command}/")
@@ -528,6 +497,7 @@ def main_export(filename):
     """Shows basic usage of the Tasks API.
     Prints the title and ID of the first 10 task lists.
     """
+    print(filename)
     command = "rlcomp"
     creds = None
     # The file token.json stores the user's access and refresh tokens, and is
@@ -570,48 +540,42 @@ def main_export(filename):
         print(err)
 
     # ===========================================================   command section ============
-    # if command == "rprint" or command == "r": # I NEED THIS TO CREATE ORGMODE AGENDA
-    #     tarem = tasks_read_remote(service, TASKLIST)
-    #     #print(tarem)
-    #     print()
-    #     for i in dict2org(tarem): print(i)
-    # elif command == "lprint" or command == "l": # I dont need it really - just to see
-    #     taloc = tasks_read_file()
-    #     print(taloc)
-    #     print()
-    #     for i in dict2org(taloc): print(i)
-    #     res = org2dict(   dict2org(taloc)  )
-    #     print()
-    #     print(res)
-    #     print()
-    #     for i in dict2org(res): print(i)
+
     if command == "rlcomp" or command == "rl":
         tarem = tasks_read_remote(service, TASKLIST)
         if not os.path.exists(filename):
             print(f"X... cannot find org  file {filename}")
             sys.exit(1)
         else:
-            print(f"i... going to export ....  {filename}")
+            print(f"i... going through possible exports ....  {filename}")
         taloc = tasks_read_file(filename)
         #print(taloc)
         to_push_new, to_update = tasks_compare_rl(tarem, taloc)
         print()
-        print("_____________________ UPDATING REMOTE __________________")
+
+
+        # ----- PUSH NEW -----------------------------------------------------
         if len(to_push_new) == 0:
             print("i... nothing new to push.... ")
         else:
-            print("TO_PUSH_NEW:")
-            print(to_push_new)
+            print("___________________ preparing push new to remote ____________")
+            print(f"{fg.orange}{to_push_new}{fg.default}")
+            # ** real action ***
             add_tasks_to_remote(service, TASKLIST, taloc, to_push_new)
+            print("_____________________ ALL NEW PUSHED __________________")
         print()
 
+        # ----- UPDATE NEW --------------------------------------------------
         if len(to_update) == 0:
-            print("i... nothing to update")
+            print("i... nothing to update ...")
         else:
-            print("TO UPDATE:   (not implemented yet)")
-            print(to_update)
+            print("__________________ UPDATING EXISTING NOW:____________________")
+            print(f"{fg.red}{to_update}{fg.default}")
             for ii in to_update:
+                # ** real action ***
                 update_remote_task(service, TASKLIST, taloc, ii[0], ii[1])
+                pass
+            print("_____________________ ALL UPDATED __________________")
 
         #print("CHANGE")
         #print(res['to_update'])
@@ -623,20 +587,23 @@ def main_export(filename):
 # MAIN
 # --------------------------------------------------------------------------------
 
-#@click.command()
-#@click.argument('action')
-#@click.argument('filename', default=None)
-def main(action, filename):
-    #print(action)
-    if action == 'import':
-        #print(action)
-        main_import()
-    else:
-        print("export")
-        if filename is None:
-            print("X... give me filename")
-        main_export(filename)
-    print("finish")
+# #@click.command()
+# #@click.argument('action')
+# #@click.argument('filename', default=None)
+# def main():
+#     #print(action)
+#     action = "export"
+#     filename ="/tmp/a.org"
+#     if action == 'import':
+#         #print(action)
+#         main_import()
+#     else:
+#         print("export",  filename)
+#         if filename is None:
+#             print("X... give me filename")
+#         main_export(filename)
+#     print("finish")
 
 if __name__ == "__main__":
-    main()
+    main_export()
+    #main_import()
