@@ -8,9 +8,22 @@ import click
 import datetime as dt
 from configparser import ConfigParser
 import socket
+import glob
+import json
+
+user_glob_admin = False
+
+LOGFILENAME = "/tmp/mcinflux_backup.log"
 
 
-user_glob = True
+# ================================================================================
+#  DISK MODE FUNCTIONS
+# --------------------------------------------------------------------------------
+
+
+# ================================================================================
+#   OLDER HELPING FUNCTIONS
+# --------------------------------------------------------------------------------
 
 
 def is_int(n):
@@ -27,11 +40,6 @@ def is_int(n):
 
 def verify_files( justprint=False):
     ok = True
-    #FIS = ["~/.config/influxdb/username_local_admin",
-    #    "~/.config/influxdb/password_local_admin",
-    #    "~/.config/influxdb/username_local",
-    #    "~/.config/influxdb/password_local",
-    #    "~/.config/influxdb/server_local"]
     FIS = ["~/.config/influxdb/totalconfig.conf"]
     for i in FIS:
         if justprint:
@@ -44,8 +52,11 @@ def verify_files( justprint=False):
     return ok
 
 def get_user_pass():
-    global user_glob
-    user = user_glob # must be set
+    """
+    depends on the value of user_glob......    default True
+    """
+    global user_glob_admin
+
     FIS = ["~/.config/influxdb/totalconfig.conf"]
 
     config = ConfigParser()
@@ -53,77 +64,18 @@ def get_user_pass():
     #print( dict(config)  )
     u, p, s = None, None, None
     if "influx local" in config.sections():
-        if user:
+        if not user_glob_admin:
             u = config["influx local"]['username']
             p = config["influx local"]['password']
             s = config["influx local"]['server']
-        else:
+        else:# ADMIN
             u = config["influx local"]['username_admin']
             p = config["influx local"]['password_admin']
             s = config["influx local"]['server']
         #print(u, p, s)
     return u, p, s
-    # #print(f"D... user in gup is {user}")
-    # u, p, d = None, None, None
-    # if user:
-    #     FIu = "~/.config/influxdb/username_local"
-    #     FIp = "~/.config/influxdb/password_local"
-    #     FIu = os.path.expanduser(FIu)
-    #     FIp = os.path.expanduser(FIp)
-    #     if os.path.exists(FIu) and os.path.exists(FIp):
-    #         with open(FIu) as f:
-    #             res = f.readlines()
-    #         u = res[0].strip()
-    #         with open(FIp) as f:
-    #             res = f.readlines()
-    #         p = res[0].strip()
-    #         d = "test"
-    #     # FI = "~/.influx_userpassdb"
-    #     # FI = os.path.expanduser(FI)
-    #     # with open(FI) as f:
-    #     #     res = f.readlines()
-    #     # u = res[0].strip()
-    #     # p = res[1].strip()
-    #     # d = res[2].strip()
-    # else:
-    #     FIu = "~/.config/influxdb/username_local_admin"
-    #     FIp = "~/.config/influxdb/password_local_admin"
-    #     FIu = os.path.expanduser(FIu)
-    #     FIp = os.path.expanduser(FIp)
-    #     if os.path.exists(FIu) and os.path.exists(FIp):
-    #         with open(FIu) as f:
-    #             res = f.readlines()
-    #         u = res[0].strip()
-    #         with open(FIp) as f:
-    #             res = f.readlines()
-    #         p = res[0].strip()
-    #         d = "test"
     return u, p, d
 
-# def get_local_machine():
-#     """
-#     Sometimes:   -host  www.xxx.com  is needed  with --ssl
-#     # -host 127.0.0.1
-#     # --ssl -host http://www.ccom:8086
-#     """
-#     m = None
-#     FIm = "~/.config/influxdb/server_local"
-#     FIm = os.path.expanduser(FIm)
-#     if os.path.exists(FIm):
-#         with open(FIm) as f:
-#             res = f.readlines()
-#         m = res[0].strip()
-#         if m.find("https://") >= 0:
-#             m = m.replace("https://", "")
-#         elif m.find("http://") >= 0:
-#             m = m.replace("http://", "")
-#         elif m.find(":8086") >= 0:
-#             m = m.replace(":8086", "")
-#         if m.find("/") >= 0:
-#             m = m.replace("/", "")
-
-#     return m
-
 
 # ============================================================
 #  check if influx active
@@ -141,11 +93,17 @@ def is_infl_active():
 
 
 # ================================================================================
-#          CALL  COMMAND
+#          CALL  COMMAND  - it uses    get_user_pass()
 # --------------------------------------------------------------------------------
-def call_cmd(CMD2, database=None, fromdb=None, todb=None, silent=False, format="", rfc=False):
+def call_cmd(CMD2, database=None, fromdb=None, todb=None, silent=False, format="", rfc=False, dontusepass=False):
+    """
+    overloaded function, explanations necessary:
+     - dontusepass ...  True is for testing the DB
+    """
     u, p, s = get_user_pass()
-    m = s#get_local_machine()
+    if dontusepass:
+        u, p = None, None  # RESET
+    m = s   #get_local_machine()
     CMD = ""
     ssl = ""
     rfc3339 = ""
@@ -159,9 +117,15 @@ def call_cmd(CMD2, database=None, fromdb=None, todb=None, silent=False, format="
         CMD = f"influx {rfc3339} -username '{u}' -password '{p}'  {ssl} -host {m}  -database {database} -execute \"{CMD2}\" {format}"
         #print(CMD)
     CMDx = shlex.split(CMD)
+
+    with open(LOGFILENAME, "a") as f:
+        f.write(f"\nCMD:\n{CMDx}")
+        f.write(f"\n\n")
+
     result = sp.run(CMDx, capture_output=True, text=True )
     if result.returncode != 0:
-        print("!...  CMD :(=", CMDx, "#")
+        if not silent:
+            print(f"X...  {fg.dimgray} CMD :(= {CMDx}  #  {fg.default}")
         ok = False
     else:
         if not silent:
@@ -170,27 +134,11 @@ def call_cmd(CMD2, database=None, fromdb=None, todb=None, silent=False, format="
 
 
 # ================================================================================
-# EXPORT                separate call
+# EXPORT     1 measurement to csv           separate call
 # --------------------------------------------------------------------------------
 
-# def export_measurement(m1, db1, silent=False):
-#     print(fg.blue, f"export new measurement {m1} to {db1} ", fg.default)
-#     u, p, _ = get_user_pass()
-#     m = get_local_machine()
-#     now = dt.datetime.now().strftime("%Y%m%d_%H%M")
-#     outfilename = f"export_{db1}_{m1}_{now}.csv"
-#     CMD = ""
-#     ssl = ""
-#     if not is_int(m.split(".")[-1]):
-#         ssl = "--ssl"
-#     #
-#     CMD = f"influx -username '{u}' -password '{p}'  {ssl} -host {m}  -database {db1} -execute 'SELECT * FROM {m1}' -format csv"
-#     #
-#     with open(outfilename, "w") as f:
-#         sp.run(shlex.split(CMD), stdout=f)
-#     return "ok"
 
-def export_measurement(m1, db1, silent=False):
+def export_measurement(m1, db1, filepath=None, silent=False):
     """
     per parts
     """
@@ -207,9 +155,12 @@ def export_measurement(m1, db1, silent=False):
     hostname = socket.gethostname()
     while True:
         pg += 1
+        # allow filepath
         outfilename = f"export_{hostname}_{db1}_{m1}_{now}_{pg:02}.csv"
+        if filepath is not None:
+            outfilename = filepath
         print(f"\n{fg.yellow}i... saving {outfilename} {fg.default}")
-        CMD = f"influx -username '{u}' -password '{p}' {ssl} -host {m} -database {db1} -execute 'SELECT * FROM {m1} ORDER BY time ASC LIMIT {limit} OFFSET {offset}' -format csv"
+        CMD = f"influx -username '{u}' -password '{p}' {ssl} -host {m} -database {db1} -execute 'SELECT * FROM {m1} ORDER BY time ASC LIMIT {limit} OFFSET {offset}' -format csv -precision rfc3339"
         result = sp.run(shlex.split(CMD), capture_output=True, text=True)
         if not result.stdout.strip():
             break
@@ -217,17 +168,26 @@ def export_measurement(m1, db1, silent=False):
             f.write(result.stdout)
         offset += limit
     return "ok"
+
+
 # ================================================================================
-# backup                 separate call
+# backup ALL                  separate call      backup ONE  database too
 # --------------------------------------------------------------------------------
 
-def backup_portable(PATH):
+def backup_portable(PATH, database=None):
+    """
+    if database given, try to backup one database
+    """
+    dbstring = ""
+    if database is not None:
+        dbstring = f" -database {database} "
     print(fg.blue, f"backing up", fg.default)
-    CMD = f"influxd backup -skip-errors -portable  {os.path.expanduser(PATH)}/ "
-    CMD = f"influxd backup  -portable  {os.path.expanduser(PATH)}/ "
+    #CMD = f"influxd backup -skip-errors -portable  {os.path.expanduser(PATH)}/ "
+    CMD = f"influxd backup  -portable {dbstring}   {os.path.expanduser(PATH)}/ "
     CMDx = shlex.split(CMD)
-    with open("/tmp/mcdebu.log", "a") as f:
+    with open(LOGFILENAME, "a") as f:
         f.write("\n\n")
+        f.write(f"\n* BACKING UP {database} to  {PATH}\n")
         f.write(CMD + "\n")
         f.write("CMDx\n")
         f.write(f"{CMDx}\n")
@@ -235,17 +195,150 @@ def backup_portable(PATH):
     #---------------------------------------------------
 
 
+# ================================================================================
+# restore                  separate call
+# --------------------------------------------------------------------------------
+def restore_portable_get_oldname(PATH, database=None):
+    """
+    extract oldname from manifest
+    """
+    dbstring = ""
+    if database is  None:
+        with open(LOGFILENAME, "a") as f:
+            f.write(f"\nIMPOSSIBLE TO RESTORE FULL INFLUX\ndo database after database\n\n")
+        return None
+    manifest_file = glob.glob(f"{PATH}/*manifest")
+    if len(manifest_file) != 1:
+        with open(LOGFILENAME, "a") as f:
+            f.write(f"\nmanifest files != 1 {manifest_file} \n\n")
+        return None
 
-def show_databases():
-    print(fg.blue, "... showing database ...", fg.default)
-    res = call_cmd( " SHOW DATABASES " )
+    # --------------------------------------------------------
+    manidbs = None
+    with open(LOGFILENAME, "a") as f:
+        f.write(f"\nmanifest_file:    {manifest_file} \n\n")
+
+    with open(manifest_file[0], "r") as f:
+        manifest = json.load(f)
+
+
+        with open(LOGFILENAME, "a") as f:
+            f.write(f"\nmanifest_json[files]:    {manifest['files']} \n\n")
+
+        if manifest['files'] is None:
+            return None
+
+        manidbs = { entry['database'] for entry in manifest['files'] }
+
+        with open(LOGFILENAME, "a") as f:
+            f.write(f"\nmanifest dbs type:    {manidbs}  {type(manidbs)}  ==set\n\n")
+            f.write(f"\nmanifest dbs len :    {manidbs}  {len(manidbs)}    ==1\n\n")
+            ##f.write(f"\nmanifest:    {manidbs}  {manidbs[0]}    ==1\n\n")
+
+        if len(manidbs) > 1:
+            with open(LOGFILENAME, "a") as f:
+                f.write(f"\n problem - manifest file databases != 1 {manidbs} \n\n")
+            return None
+    original_database = next(iter(manidbs))
+    return original_database
+
+
+def restore_portable(PATH, database=None):
+    """
+    if database given, try to backup one database
+    """
+    dbstring = ""
+    if database is  None:
+        with open(LOGFILENAME, "a") as f:
+            f.write(f"\nIMPOSSIBLE TO RESTORE FULL INFLUX\ndo database after database\n\n")
+        return
+
+    original_database = restore_portable_get_oldname(PATH, database)
+
+    if database is not None:
+        dbstring = f" -db {original_database} -newdb {database} "
+    print(fg.blue, f"backing up", fg.default)
+    #CMD = f"influxd backup -skip-errors -portable  {os.path.expanduser(PATH)}/ "
+    CMD = f"influxd restore  -portable  {dbstring}   {os.path.expanduser(PATH)}/ "
+    CMDx = shlex.split(CMD)
+    with open(LOGFILENAME, "a") as f:
+        f.write(f"\n* RESTORING {database} from  {PATH}\n")
+        f.write(CMD + "\n")
+        f.write("CMDx:  ")
+        f.write(f"{CMDx}\n")
+    sp.run(CMD, shell=True)
+    with open(LOGFILENAME, "a") as f:
+        f.write(f"\n... should be restored now\n")
+    #---------------------------------------------------
+
+
+
+def show_databases(dontusepass=False, silent=False):
+    """
+    allows to test with no AUTH
+    """
+    if not silent:
+        print(fg.blue, "... showing present databases ...", fg.default)
+    res = call_cmd( " SHOW DATABASES ", dontusepass=dontusepass, silent=silent) # shows on screen in gray
+    res = res.strip("\n")
     #print(res)
-    res = res.split("\n")[3:]
-    print(res, ":")
+    res = res.split("\n")[3:]  # remove  'name: databases;  name ;  ---- ;
+    #print("D...:,res, ":")  # HERE _internal and i_am_ ARE PRESENT......
+    # REMOVING here
     res = [ x for x in res if (len(x) > 0) and (x[0] != "_") and (x[0] != "-")  and (x.find("name") < 0)and (x.find("i_am_") < 0)  ]
-    print(res)
+    # final stage
+    #print(res)
     return res
 
+
+# ================================================================================
+
+def show_grants(dontusepass=False, silent=False):
+    """
+
+    """
+    u, p, s = get_user_pass()
+    if not silent:
+        print(fg.blue, "... showing present GRANTS  ...", fg.default)
+    res = call_cmd( f' SHOW GRANTS FOR "{u}" ', dontusepass=dontusepass, silent=silent) # shows on screen in gray
+    res = res.strip("\n")
+    if res.find("ERR:") >= 0:
+        return None
+    #print("S...", res)
+    res = res.split("\n")[2:]  # remove  'database privileges ;  ---- ;
+    priv = {}
+    for i in res:
+        a = i.split()
+        priv[a[0]] = " ".join(a[1:])
+    #print(f"D... {priv}")
+    return priv
+
+# ================================================================================
+
+def show_users(dontusepass=False, silent=False):
+    """
+
+    """
+    #u, p, s = get_user_pass()
+    if not silent:
+        print(fg.blue, "... showing present USERS  ...", fg.default)
+    res = call_cmd( f' SHOW USERS ', dontusepass=dontusepass, silent=silent) # shows on screen in gray
+    res = res.strip("\n")
+    if res.find("ERR:") >= 0:
+        return None
+    #print("S...", res)
+    res = res.split("\n")[2:]  # remove  'database privileges ;  ---- ;
+    priv = {}
+    for i in res:
+        a = i.split()
+        isadm = " ".join(a[1:])
+        if isadm == "true":
+            priv[a[0]] = "ADMIN"
+        else:
+            priv[a[0]] = "     "
+    #print(f"D... {priv}")
+    return priv
+
 def create_database( db ):
     print(fg.blue, "creating database", fg.default)
     res = call_cmd( f"  CREATE DATABASE '{db}' " ).strip().split("\n")
@@ -270,10 +363,13 @@ def show_measurements(database):
     print(res)
     return res
 
-def copy_measurement(m1, db1, db2, silent=False):
+def copy_measurement(m1, db1, db2, silent=False, new_measurement_name=None):
     if not silent:
         print(fg.blue, f"copy measurement {m1} from {db1} to {db2}", fg.default)
     CMD = f"SELECT * INTO {db2}..{m1} FROM {db1}..{m1} group by *"
+    if new_measurement_name is not None:
+        # THE CORRECT ORDER!!!
+        CMD = f"SELECT * INTO {db2}..{new_measurement_name} FROM {db1}..{m1} group by *"
     if not silent:
         print(CMD)
     res = CMD
