@@ -330,6 +330,7 @@ def my_callback(inp):
                  ############ --------- ############
                 if 'C' == inp: #### KEY #### PORT 5000 !!
                     code = os.path.expanduser("flashcam")
+                    code = os.path.expanduser("pogucam")
 
                     mXY=""
                     if len(screenset)>0: mXY=f"-X {screenset.pop(0)}"
@@ -348,11 +349,13 @@ def my_callback(inp):
                     CMD = "terminator -e 'BASH_ENV=~/.bashrc bash -c \"  export PATH=$PATH:$HOME/.local/bin;  "+code+" uni http://"+alldics_origin[i]['hostname']+":5000/video  "+PASFILE+" \" ; sleep 5'"
 
                     CMD = "xterm -T "+alldics_origin[i]['hostname']+":5000  -geometry 80x5 -bg black -fg yellow -e 'BASH_ENV=~/.bashrc bash -c \" export PATH=$PATH:$HOME/.local/bin; "+code+" uni http://"+alldics_origin[i]['hostname']+f":5000/video {mXY} "+PASFILE+" \" ;  sleep 1' &"
+
+                    CMD = "xterm -T "+alldics_origin[i]['hostname']+":5000  -geometry 130x5 -bg black -fg yellow -e 'BASH_ENV=~/.bashrc bash -c \" export PATH=$PATH:$HOME/.local/bin; "+code+"  http://"+alldics_origin[i]['hostname']+f":5000/video  \" ' &"
                     print(CMD)
                     print(CMD)
                     print(CMD)
-                    #os.system(CMD)
-                    launch_command(CMD)
+                    os.system(CMD)
+                    #launch_command(CMD)
 
                     time.sleep(2)
                                   #### camera ##### 8000
@@ -386,7 +389,7 @@ def my_callback(inp):
 
                     CMD = "xterm -T +"+alldics_origin[i]['hostname']+":8000 -geometry 80x5 -bg black -fg yellow -e 'BASH_ENV=~/.bashrc bash -c \" export PATH=$PATH:$HOME/.local/bin; "+code+" uni http://"+alldics_origin[i]['hostname']+f":8000/video {mXY} "+PASFILE+" \" ' &"
                     # POGUCAM
-                    CMD = "xterm -T +"+alldics_origin[i]['hostname']+":8000 -geometry 80x5 -bg black -fg yellow -e 'BASH_ENV=~/.bashrc bash -c \" export PATH=$PATH:$HOME/.local/bin; "+code+"  http://"+alldics_origin[i]['hostname']+f":8000/video  \"  ' &"
+                    CMD = "xterm -T +"+alldics_origin[i]['hostname']+":8000 -geometry 130x5 -bg black -fg yellow -e 'BASH_ENV=~/.bashrc bash -c \" export PATH=$PATH:$HOME/.local/bin; "+code+"  http://"+alldics_origin[i]['hostname']+f":8000/video  \"  ' &"
                     print(CMD)
                     #print(CMD)
                     ##print(CMD)
